package svc

import (
	"applet/app/admin/md"
	md2 "applet/app/customer/md"
	svc2 "applet/app/customer/svc"
	"applet/app/db"
	"applet/app/db/model"
	enum2 "applet/app/enum"
	"applet/app/utils"
	"errors"
	"time"
)

func SelfSupportForSchoolUserUpdate(req md.SelfSupportForSchoolUserUpdateReq) (err error) {
	//1、删除当前用户&&当前单位下的所有身份对应的 `class_with_user` 记录
	var userIdentities []model.UserIdentity
	err = db.Db.Where("uid =? AND enterprise_id =?", req.Uid, req.EnterpriseId).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//2、新增 / 编辑 数据
	now := time.Now()
	selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
	selfSupportForSchoolInfoDb.Set(req.EnterpriseId)
	selfSupportForSchoolInfo, err := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
	if err != nil {
		return
	}
	if selfSupportForSchoolInfo == nil {
		return errors.New("当前学校暂未完成《一脸通行入驻》")
	}

	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(req.Uid)

	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()

	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	var newUserIdentityIds []string
	for _, v := range req.BindUserIdentities {
		if v.UserIdentityId == 0 {
			// 新增
			if v.ClassId == -1 {
				//TODO::为老师身份
				_, err3 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
					Uid:          req.Uid,
					Name:         v.Name,
					IdNo:         v.IdNo,
					CertType:     v.CertType,
					Kind:         enum2.UserIdentityKindForCommon,
					Identity:     enum2.UserIdentityForSelfSupportForTeacher,
					EnterpriseId: req.EnterpriseId,
					Memo:         "",
					State:        enum2.UserIdentityStateForNormal,
					CreateAt:     now.Format("2006-01-02 15:04:05"),
					UpdateAt:     now.Format("2006-01-02 15:04:05"),
				})
				if err3 != nil {
					_ = session.Rollback()
					return err3
				}
				continue
			}

			if v.ClassId == -2 {
				//TODO::为工作人员身份
				_, err3 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
					Uid:          req.Uid,
					Name:         v.Name,
					IdNo:         v.IdNo,
					CertType:     v.CertType,
					Kind:         enum2.UserIdentityKindForWorker,
					Identity:     enum2.UserIdentityForSelfSupportForWorker,
					EnterpriseId: req.EnterpriseId,
					Memo:         "",
					State:        enum2.UserIdentityStateForNormal,
					CreateAt:     now.Format("2006-01-02 15:04:05"),
					UpdateAt:     now.Format("2006-01-02 15:04:05"),
				})
				if err3 != nil {
					_ = session.Rollback()
					return err3
				}
				continue
			}

			insertId, err1 := userIdentityDb.UserIdentityInsertBySession(session, &model.UserIdentity{
				Uid:          req.Uid,
				Name:         v.Name,
				IdNo:         v.IdNo,
				CertType:     v.CertType,
				Kind:         enum2.UserIdentityKindForCommon,
				Identity:     enum2.UserIdentityForSelfSupportForStudent,
				EnterpriseId: req.EnterpriseId,
				Memo:         "",
				State:        enum2.UserIdentityStateForNormal,
				CreateAt:     now.Format("2006-01-02 15:04:05"),
				UpdateAt:     now.Format("2006-01-02 15:04:05"),
			})
			if err1 != nil {
				_ = session.Rollback()
				return err1
			}

			_, err2 := classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
				UserIdentityId: insertId,
				ClassId:        v.ClassId,
				CreateAt:       now.Format("2006-01-02 15:04:05"),
				UpdateAt:       now.Format("2006-01-02 15:04:05"),
			})
			if err2 != nil {
				_ = session.Rollback()
				return err1
			}

			selfSupportForUserFaceInfoDb.Set(insertId)
			_, err = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoInsert(&model.SelfSupportForUserFaceInfo{
				EnterpriseId:                    req.EnterpriseId,
				UserIdentityId:                  insertId,
				CollectFaceType:                 1, //默认个采
				SchoolCode:                      selfSupportForSchoolInfo.SchoolCode,
				SchoolStdCode:                   selfSupportForSchoolInfo.SchoolStdCode,
				ParentUserId:                    "",
				ParentLogonId:                   "",
				UserId:                          "",
				SchoolFacePassStatus:            "CLOSE",
				SchoolFacePaymentStatus:         "CLOSE",
				ConcentrateSchoolFacePassStatus: 1,
				CreateAt:                        now.Format("2006-01-02 15:04:05"),
				UpdateAt:                        now.Format("2006-01-02 15:04:05"),
			})
			if err != nil {
				return err
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(insertId))
		} else {
			//编辑
			identity, err2 := userIdentityDb.GetUserIdentity(v.UserIdentityId)
			if err != nil {
				_ = session.Rollback()
				return err2
			}
			if identity == nil {
				_ = session.Rollback()
				return errors.New("未查询到对应的身份信息记录")
			}
			identity.IdNo = v.IdNo
			identity.CertType = v.CertType
			identity.Name = v.Name
			if v.ClassId == -1 {
				//TODO::为老师身份
				identity.Identity = enum2.UserIdentityForSelfSupportForTeacher
			} else if v.ClassId == -2 {
				//TODO::为工作人员
				identity.Identity = enum2.UserIdentityForSelfSupportForWorker
			} else {
				_, err3 := classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
					UserIdentityId: v.UserIdentityId,
					ClassId:        v.ClassId,
					CreateAt:       now.Format("2006-01-02 15:04:05"),
					UpdateAt:       now.Format("2006-01-02 15:04:05"),
				})
				if err3 != nil {
					_ = session.Rollback()
					return err3
				}
			}
			_, err3 := userIdentityDb.UserIdentityUpdateBySession(session, v.UserIdentityId, identity, "id_no", "cert_type", "name", "identity")
			if err3 != nil {
				_ = session.Rollback()
				return err3
			}

			newUserIdentityIds = append(newUserIdentityIds, utils.IntToStr(v.UserIdentityId))
		}
	}

	//3、删除需要删除的身份信息
	for _, v := range userIdentityIds {
		if !utils.InArr(utils.IntToStr(v), newUserIdentityIds) {
			_, err = session.Where("id = ?", v).Delete(model.UserIdentity{})
			if err != nil {
				_ = session.Rollback()
				return
			}

			_, err = session.Where("user_identity_id = ?", v).Delete(model.SelfSupportForUserFaceInfo{})
			if err != nil {
				_ = session.Rollback()
				return
			}
		}
	}
	return session.Commit()
}

func SelfSupportForSchoolUserDelete(req md.SelfSupportForSchoolUserDeleteReq) (err error) {
	//1、删除 class_with_user
	var userIdentities []model.UserIdentity
	err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("uid", req.Uids).Find(&userIdentities)
	if err != nil {
		return
	}
	var userIdentityIds []int
	for _, v := range userIdentities {
		userIdentityIds = append(userIdentityIds, v.Id)
	}
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	//2、删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("uid", req.Uids).Delete(model.UserIdentity{})
	if err != nil {
		return
	}

	//3、删除 self_support_for_user_face_info
	_, err = db.Db.In("user_identity_id", userIdentityIds).Delete(model.SelfSupportForUserFaceInfo{})
	if err != nil {
		return
	}

	return
}

func SelfSupportForSchoolStudentList(req md.SelfSupportForSchoolStudentListReq) (resp []md.SelfSupportForSchoolStudentListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, 0, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, 0, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}
	sess := db.Db.Where("user_identity.enterprise_id =?", req.EnterpriseId).
		And("identity =?", enum2.UserIdentityForSelfSupportForStudent).
		And("state =?", enum2.UserIdentityStateForNormal)
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.IdNo != "" {
		sess.And("user_identity.id_no like ?", "%"+req.IdNo+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.UserIdentityWithUser
	count, err = sess.
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Join("LEFT", "self_support_for_user_face_info", "user_identity.id = self_support_for_user_face_info.user_identity_id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.SelfSupportForSchoolStudentListResp{
			IdNo:                    v.UserIdentity.IdNo,
			CertType:                v.UserIdentity.CertType,
			ParentPhone:             v.User.Phone,
			Name:                    v.UserIdentity.Name,
			Grade:                   v.Grade.Name,
			GradeId:                 v.Grade.Id,
			Class:                   v.Class.Name,
			ClassId:                 v.Class.Id,
			UserIdentityId:          v.UserIdentity.Id,
			CollectFaceType:         v.SelfSupportForUserFaceInfo.CollectFaceType,
			SchoolFacePassStatus:    v.SelfSupportForUserFaceInfo.SchoolFacePassStatus,
			SchoolFacePaymentStatus: v.SelfSupportForUserFaceInfo.SchoolFacePaymentStatus,
		})
	}
	return
}

func SelfSupportForSchoolTeacherList(req md.SelfSupportForSchoolTeacherListReq) (resp []md.SelfSupportForSchoolTeacherListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()

	sess := db.Db.Where("user_identity.enterprise_id =?", req.EnterpriseId).And("user_identity.identity =?", enum2.UserIdentityForSelfSupportForTeacher)
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.IdNo != "" {
		sess.And("user_identity.id_no like ?", "%"+req.IdNo+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.UserIdentityWithUser
	count, err = sess.
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "self_support_for_user_face_info", "user_identity.id = self_support_for_user_face_info.user_identity_id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.SelfSupportForSchoolTeacherListResp{
			UserIdentityId:          v.UserIdentity.Id,
			IdNo:                    v.UserIdentity.IdNo,
			CertType:                v.UserIdentity.CertType,
			Phone:                   v.User.Phone,
			Name:                    v.UserIdentity.Name,
			CollectFaceType:         v.SelfSupportForUserFaceInfo.CollectFaceType,
			SchoolFacePassStatus:    v.SelfSupportForUserFaceInfo.SchoolFacePassStatus,
			SchoolFacePaymentStatus: v.SelfSupportForUserFaceInfo.SchoolFacePaymentStatus,
		})
	}
	return
}

func SelfSupportForSchoolStudentUpdate(req md.SelfSupportForSchoolStudentUpdateReq) (err error) {
	session := db.Db.NewSession()
	defer session.Close()
	session.Begin()

	//1、修改 `user_identity`
	userIdentityDb := db.UserIdentityDb{}
	userIdentityDb.Set(0)
	userIdentity, err := userIdentityDb.GetUserIdentity(req.UserIdentityId)
	if err != nil {
		return
	}
	if userIdentity == nil {
		return errors.New("未查询到对应记录")
	}
	userIdentity.IdNo = req.IdNo
	userIdentity.CertType = req.CertType
	userIdentity.Name = req.Name
	_, err = userIdentityDb.UserIdentityUpdate(req.UserIdentityId, userIdentity, "id_no", "name", "cert_type")
	if err != nil {
		return
	}

	//2、更新 `class_with_user`
	_, err = session.Where("user_identity_id =?", req.UserIdentityId).Delete(model.ClassWithUser{})
	if err != nil {
		_ = session.Rollback()
		return
	}

	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	_, err = classWithUserDb.ClassWithUserInsertBySession(session, &model.ClassWithUser{
		UserIdentityId: req.UserIdentityId,
		ClassId:        req.ClassId,
		CreateAt:       time.Now().Format("2006-01-02 15:04:05"),
		UpdateAt:       time.Now().Format("2006-01-02 15:04:05"),
	})

	//3、更新 self_support_for_user_face_info
	selfSupportForUserFaceInfoDb := db.SelfSupportForUserFaceInfoDb{}
	selfSupportForUserFaceInfoDb.Set(req.UserIdentityId)
	info, err := selfSupportForUserFaceInfoDb.GetSelfSupportForUserFaceInfo()
	if err != nil {
		_ = session.Rollback()
		return
	}
	if info == nil {
		now := time.Now()
		selfSupportForSchoolInfoDb := db.SelfSupportForSchoolInfoDb{}
		selfSupportForSchoolInfoDb.Set(req.EnterpriseId)
		selfSupportForSchoolInfo, err1 := selfSupportForSchoolInfoDb.GetSelfSupportForSchoolInfo()
		if err1 != nil {
			return
		}
		if selfSupportForSchoolInfo == nil {
			return errors.New("当前学校暂未完成《一脸通行入驻》")
		}
		info = &model.SelfSupportForUserFaceInfo{
			EnterpriseId:                    req.EnterpriseId,
			UserIdentityId:                  req.UserIdentityId,
			CollectFaceType:                 req.CollectFaceType,
			SchoolCode:                      selfSupportForSchoolInfo.SchoolCode,
			SchoolStdCode:                   selfSupportForSchoolInfo.SchoolStdCode,
			ParentUserId:                    "",
			ParentLogonId:                   "",
			UserId:                          "",
			SchoolFacePassStatus:            "CLOSE",
			SchoolFacePaymentStatus:         "CLOSE",
			ConcentrateSchoolFacePassStatus: 1,
			CreateAt:                        now.Format("2006-01-02 15:04:05"),
			UpdateAt:                        now.Format("2006-01-02 15:04:05"),
		}
		_, err1 = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoInsert(info)
		if err1 != nil {
			return err1
		}
	} else {
		info.CollectFaceType = req.CollectFaceType
		_, err = selfSupportForUserFaceInfoDb.SelfSupportForUserFaceInfoUpdate(info, "collect_face_type")
		if err != nil {
			_ = session.Rollback()
		}
	}

	return session.Commit()
}

func SelfSupportForSchoolStudentDelete(req md.SelfSupportForSchoolStudentDeleteReq) (err error) {
	//1、删除 class_with_user
	_, err = db.Db.In("user_identity_id", req.UserIdentityIds).Delete(model.ClassWithUser{})
	if err != nil {
		return
	}

	//2、删除 user_identity
	_, err = db.Db.Where("enterprise_id =?", req.EnterpriseId).In("id", req.UserIdentityIds).Delete(model.UserIdentity{})
	if err != nil {
		return
	}

	//3、删除 self_support_for_user_face_info
	_, err = db.Db.In("user_identity_id", req.UserIdentityIds).Delete(model.SelfSupportForUserFaceInfo{})
	if err != nil {
		return
	}
	return
}

func SelfSupportForSchoolStudentAdmission(req md.SelfSupportForSchoolStudentAdmissionReq) (err error) {
	//1、判断 "按年级" / "按班级" 升级
	if req.ClassId != 0 {
		// 删除 class_with_user 记录
		_, err = db.Db.Where("class_id = ?", req.ClassId).Delete(model.ClassWithUser{})
		if err != nil {
			return
		}
	}
	if req.GradeId != 0 {
		// 查找班级记录
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err1 := classDb.FindClass()
		if err1 != nil {
			return err1
		}
		var classesIds []int
		for _, v := range *classes {
			classesIds = append(classesIds, v.Id)
		}

		// 删除 class_with_user 记录
		_, err = db.Db.In("class_id", classesIds).Delete(model.ClassWithUser{})
		if err != nil {
			return
		}
	}

	return
}

func SelfSupportForSchoolWorkerList(req md.SelfSupportForSchoolWorkerListReq) (resp []md.SelfSupportForSchoolWorkerListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()

	sess := db.Db.Where("user_identity.enterprise_id =?", req.EnterpriseId).And("user_identity.identity =?", enum2.UserIdentityForSelfSupportForWorker)
	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.IdNo != "" {
		sess.And("user_identity.id_no like ?", "%"+req.IdNo+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.UserIdentityWithUser
	count, err = sess.
		Join("LEFT", "user", "user_identity.uid = user.id").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	for _, v := range m {
		resp = append(resp, md.SelfSupportForSchoolWorkerListResp{
			UserIdentityId: v.UserIdentity.Id,
			IdNo:           v.UserIdentity.IdNo,
			CertType:       v.UserIdentity.CertType,
			Phone:          v.User.Phone,
			Name:           v.UserIdentity.Name,
			CreateAt:       v.UserIdentity.CreateAt,
		})
	}
	return
}

func SelfSupportForSchoolGradeList(req md.SelfSupportForSchoolGradeListReq) (m []*model.Grade, count int64, err error) {
	sess := db.Db.Where("enterprise_id =?", req.EnterpriseId)
	if req.Name != "" {
		sess.And("name like ?", "%"+req.Name+"%")
	}
	count, err = sess.Asc("id").Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}
	return
}

func SelfSupportForSchoolClassList(req md.SelfSupportForSchoolClassListReq) (m []*model.Class, count int64, err error) {
	sess := db.Db.Where("enterprise_id =?", req.EnterpriseId)
	if req.Name != "" {
		sess.And("name like ?", "%"+req.Name+"%")
	}
	if req.GradeId != 0 {
		sess.And("grade_id = ?", req.GradeId)
	}
	count, err = sess.Asc("id").Limit(req.Limit, (req.Page-1)*req.Limit).FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}
	return
}

func SelfSupportForSchoolOrdList(req md.SelfSupportForSchoolOrdListReq) (resp []md.SelfSupportForSchoolOrdListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, 0, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, 0, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}

	sess := db.Db.Desc("self_support_for_school_ord.id")
	if req.EnterpriseId != 0 {
		sess.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.StartDate != "" {
		sess.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
	}
	if req.OrderStatus != 0 {
		sess.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
	}
	if req.OutTradeNo != "" {
		sess.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.EnterpriseKind != 0 {
		sess.And("enterprise.kind = ?", req.EnterpriseKind)
	}
	if req.IsTeacher != 0 {
		if req.IsTeacher == 1 {
			sess.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
		if req.IsTeacher == 2 {
			sess.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
	}

	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.SelfSupportForSchoolOrdWithUserIdentity
	count, err = sess.
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).Desc("self_support_for_school_ord.face_time").FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	//查询出所有的设备
	var deviceList []*model.Device
	err = db.Db.Where("enterprise_id != 0").Find(&deviceList)
	if err != nil {
		return nil, 0, err
	}
	var deviceListMapping = map[string]model.Device{}
	for _, v := range deviceList {
		deviceListMapping[v.DeviceSn] = *v
	}

	for _, v := range m {
		resp = append(resp, md.SelfSupportForSchoolOrdListResp{
			Id:               v.SelfSupportForSchoolOrd.Id,
			EnterpriseId:     v.UserIdentity.EnterpriseId,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.UserIdentity.Uid,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityName: v.SelfSupportForSchoolOrd.Consumer,
			TotalPrice:       v.SelfSupportForSchoolOrd.TradeAmount,
			OutTradeNo:       v.SelfSupportForSchoolOrd.OutOrderNo,
			TradeNo:          v.SelfSupportForSchoolOrd.TradeNo,
			OrderStatus:      v.SelfSupportForSchoolOrd.OrderStatus,
			FaceTime:         v.SelfSupportForSchoolOrd.FaceTime,
			Phone:            v.User.Phone,
			Name:             v.UserIdentity.Name,
			Grade:            v.Grade.Name,
			GradeId:          v.Grade.Id,
			Class:            v.Class.Name,
			ClassId:          v.Class.Id,
			DeviceSn:         v.SelfSupportForSchoolOrd.DeviceSn,
			ShopName:         deviceListMapping[v.SelfSupportForSchoolOrd.DeviceSn].Name,
		})
	}
	return
}

func SelfSupportForSchoolOrdStatistics(req md.SelfSupportForSchoolOrdListReq) (personNum, count int64, consumeAmount, alreadyPayAmount, waitPayAmount, refundPayAmount float64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return 0, 0, 0, 0, 0, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return 0, 0, 0, 0, 0, 0, err
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return 0, 0, 0, 0, 0, 0, err
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}

	sess1 := db.Db.Where("1=1")
	sess2 := db.Db.Where("1=1")
	sess3 := db.Db.Where("1=1")
	sess4 := db.Db.Where("1=1")
	sess5 := db.Db.Where("1=1")
	sess6 := db.Db.Where("1=1")
	if req.EnterpriseId != 0 {
		sess1.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
		sess2.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
		sess3.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
		sess4.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
		sess5.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
		sess6.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.StartDate != "" {
		sess1.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
		sess2.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
		sess3.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
		sess4.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
		sess5.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
		sess6.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess1.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
		sess2.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
		sess3.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
		sess4.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
		sess5.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
		sess6.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
	}
	if req.OrderStatus != 0 {
		sess1.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
		sess2.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
		sess3.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
		sess4.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
		sess5.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
		sess6.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
	}
	if req.OutTradeNo != "" {
		sess1.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
		sess2.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
		sess3.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
		sess4.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
		sess5.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
		sess6.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.EnterpriseKind != 0 {
		sess1.And("enterprise.kind = ?", req.EnterpriseKind)
		sess2.And("enterprise.kind = ?", req.EnterpriseKind)
		sess3.And("enterprise.kind = ?", req.EnterpriseKind)
		sess4.And("enterprise.kind = ?", req.EnterpriseKind)
		sess5.And("enterprise.kind = ?", req.EnterpriseKind)
		sess6.And("enterprise.kind = ?", req.EnterpriseKind)
	}
	if req.IsTeacher != 0 {
		if req.IsTeacher == 1 {
			sess1.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess2.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess3.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess4.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess5.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess6.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
		if req.IsTeacher == 2 {
			sess1.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess2.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess3.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess4.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess5.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
			sess6.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
	}

	if req.Name != "" {
		sess1.And("user_identity.name like ?", "%"+req.Name+"%")
		sess2.And("user_identity.name like ?", "%"+req.Name+"%")
		sess3.And("user_identity.name like ?", "%"+req.Name+"%")
		sess4.And("user_identity.name like ?", "%"+req.Name+"%")
		sess5.And("user_identity.name like ?", "%"+req.Name+"%")
		sess6.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess1.And("user.phone like ?", "%"+req.Phone+"%")
		sess2.And("user.phone like ?", "%"+req.Phone+"%")
		sess3.And("user.phone like ?", "%"+req.Phone+"%")
		sess4.And("user.phone like ?", "%"+req.Phone+"%")
		sess5.And("user.phone like ?", "%"+req.Phone+"%")
		sess6.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess1.In("user_identity.id", classWithUserIdentityIdsOne)
		sess2.In("user_identity.id", classWithUserIdentityIdsOne)
		sess3.In("user_identity.id", classWithUserIdentityIdsOne)
		sess4.In("user_identity.id", classWithUserIdentityIdsOne)
		sess5.In("user_identity.id", classWithUserIdentityIdsOne)
		sess6.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess1.In("user_identity.id", classWithUserIdentityIdsTwo)
		sess2.In("user_identity.id", classWithUserIdentityIdsTwo)
		sess3.In("user_identity.id", classWithUserIdentityIdsTwo)
		sess4.In("user_identity.id", classWithUserIdentityIdsTwo)
		sess5.In("user_identity.id", classWithUserIdentityIdsTwo)
		sess6.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.SelfSupportForSchoolOrdWithUserIdentity
	personNum, err = sess1.
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		GroupBy("self_support_for_school_ord.user_identity_id").
		FindAndCount(&m)
	if err != nil {
		return 0, 0, 0, 0, 0, 0, err
	}

	count, err = sess2.
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		FindAndCount(&m)
	if err != nil {
		return 0, 0, 0, 0, 0, 0, err
	}

	var mm db.SelfSupportForSchoolOrdWithUserIdentity
	consumeAmount, err = sess3.
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Sum(mm, "self_support_for_school_ord.trade_amount")
	if err != nil {
		return 0, 0, 0, 0, 0, 0, err
	}

	waitPayAmount, err = sess4.And("self_support_for_school_ord.order_status = ?", enum2.SelfSupportForSchoolOrdOrderStatusForWait).
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Sum(mm, "self_support_for_school_ord.trade_amount")
	if err != nil {
		return 0, 0, 0, 0, 0, 0, err
	}

	alreadyPayAmount, err = sess5.And("self_support_for_school_ord.order_status = ?", enum2.SelfSupportForSchoolOrdOrderStatusForSuccess).
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Sum(mm, "self_support_for_school_ord.trade_amount")
	if err != nil {
		return 0, 0, 0, 0, 0, 0, err
	}

	refundPayAmount, err = sess6.And("self_support_for_school_ord.order_status = ?", enum2.SelfSupportForSchoolOrdOrderStatusForRefund).
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Sum(mm, "self_support_for_school_ord.trade_amount")
	if err != nil {
		return 0, 0, 0, 0, 0, 0, err
	}

	return
}

func SelfSupportForSchoolOrdListExport(req md.SelfSupportForSchoolOrdListReq) (resp []md.SelfSupportForSchoolOrdListResp, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}

	sess := db.Db.Desc("self_support_for_school_ord.id")
	if req.EnterpriseId != 0 {
		sess.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.StartDate != "" {
		sess.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
	}
	if req.OrderStatus != 0 {
		sess.And("self_support_for_school_ord.order_status = ?", req.OrderStatus)
	}
	if req.OutTradeNo != "" {
		sess.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.IsTeacher != 0 {
		if req.IsTeacher == 1 {
			sess.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
		if req.IsTeacher == 2 {
			sess.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
	}

	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.SelfSupportForSchoolOrdWithUserIdentity
	err = sess.
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = user_identity.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Desc("self_support_for_school_ord.face_time").Find(&m)
	if err != nil {
		return nil, err
	}

	//查询出所有的设备
	var deviceList []*model.Device
	err = db.Db.Where("enterprise_id != 0").Find(&deviceList)
	if err != nil {
		return nil, err
	}
	var deviceListMapping = map[string]model.Device{}
	for _, v := range deviceList {
		deviceListMapping[v.DeviceSn] = *v
	}

	for _, v := range m {
		resp = append(resp, md.SelfSupportForSchoolOrdListResp{
			EnterpriseId:     v.UserIdentity.EnterpriseId,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.UserIdentity.Uid,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityName: v.SelfSupportForSchoolOrd.Consumer,
			TotalPrice:       v.SelfSupportForSchoolOrd.TradeAmount,
			OutTradeNo:       v.SelfSupportForSchoolOrd.OutOrderNo,
			TradeNo:          v.SelfSupportForSchoolOrd.TradeNo,
			OrderStatus:      v.SelfSupportForSchoolOrd.OrderStatus,
			FaceTime:         v.SelfSupportForSchoolOrd.FaceTime,
			Phone:            v.User.Phone,
			Name:             v.UserIdentity.Name,
			Grade:            v.Grade.Name,
			GradeId:          v.Grade.Id,
			Class:            v.Class.Name,
			ClassId:          v.Class.Id,
			DeviceSn:         v.SelfSupportForSchoolOrd.DeviceSn,
			ShopName:         deviceListMapping[v.SelfSupportForSchoolOrd.DeviceSn].Name,
		})
	}
	return
}

func SelfSupportForSchoolArrearsOrdList(req md.SelfSupportForSchoolArrearsOrdListReq) (resp []md.SelfSupportForSchoolOrdListResp, count int64, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, 0, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, 0, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, 0, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}

	sess := db.Db.Desc("self_support_for_school_ord.id")
	if req.EnterpriseId != 0 {
		sess.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.IsTeacher != 0 {
		if req.IsTeacher == 1 {
			sess.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
		if req.IsTeacher == 2 {
			sess.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
	}
	if req.StartDate != "" {
		sess.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
	}
	//if req.OrderStatus != 0 {
	sess.And("self_support_for_school_ord.order_status = ?", 1) // 支付状态 (1:待支付 2:支付成功)
	//}
	if req.OutTradeNo != "" {
		sess.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.EnterpriseKind != 0 {
		sess.And("enterprise.kind = ?", req.EnterpriseKind)
	}

	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.SelfSupportForSchoolOrdWithUserIdentity
	count, err = sess.
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = self_support_for_school_ord.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Limit(req.Limit, (req.Page-1)*req.Limit).Desc("self_support_for_school_ord.face_time").FindAndCount(&m)
	if err != nil {
		return nil, 0, err
	}

	//查询出所有的设备
	var deviceList []*model.Device
	err = db.Db.Where("enterprise_id != 0").Find(&deviceList)
	if err != nil {
		return nil, 0, err
	}
	var deviceListMapping = map[string]model.Device{}
	for _, v := range deviceList {
		deviceListMapping[v.DeviceSn] = *v
	}
	for _, v := range m {
		resp = append(resp, md.SelfSupportForSchoolOrdListResp{
			EnterpriseId:     v.UserIdentity.EnterpriseId,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.UserIdentity.Uid,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityName: v.SelfSupportForSchoolOrd.Consumer,
			TotalPrice:       v.SelfSupportForSchoolOrd.TradeAmount,
			OutTradeNo:       v.SelfSupportForSchoolOrd.OutOrderNo,
			TradeNo:          v.SelfSupportForSchoolOrd.TradeNo,
			OrderStatus:      v.SelfSupportForSchoolOrd.OrderStatus,
			FaceTime:         v.SelfSupportForSchoolOrd.FaceTime,
			Phone:            v.User.Phone,
			Name:             v.UserIdentity.Name,
			Grade:            v.Grade.Name,
			GradeId:          v.Grade.Id,
			Class:            v.Class.Name,
			ClassId:          v.Class.Id,
			DeviceSn:         v.SelfSupportForSchoolOrd.DeviceSn,
			ShopName:         deviceListMapping[v.SelfSupportForSchoolOrd.DeviceSn].Name,
			CpMerchantId:     v.SelfSupportForSchoolOrd.CpMerchantId,
			DebtBusinessMsg:  v.SelfSupportForSchoolOrd.DebtBusinessMsg,
		})
	}
	return
}

func SelfSupportForSchoolArrearsOrdListExport(req md.SelfSupportForSchoolArrearsOrdListReq) (resp []md.SelfSupportForSchoolOrdListResp, err error) {
	var classWithUserIdentityIdsOne []int
	var classWithUserIdentityIdsTwo []int
	classWithUserDb := db.ClassWithUserDb{}
	classWithUserDb.Set()
	if req.ClassId != 0 {
		classWithUsers, err2 := classWithUserDb.FindUserIdentity(req.ClassId)
		if err2 != nil {
			return nil, err2
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsOne = append(classWithUserIdentityIdsOne, v.UserIdentityId)
		}
	}
	if req.GradeId != 0 {
		classDb := db.ClassDb{}
		classDb.Set(req.GradeId)
		classes, err3 := classDb.FindClass()
		if err3 != nil {
			return nil, err3
		}
		var classesId []int
		for _, v := range *classes {
			classesId = append(classesId, v.Id)
		}
		classWithUsers, err4 := classWithUserDb.FindUserIdentity(classesId)
		if err4 != nil {
			return nil, err4
		}
		for _, v := range *classWithUsers {
			classWithUserIdentityIdsTwo = append(classWithUserIdentityIdsTwo, v.UserIdentityId)
		}
	}

	sess := db.Db.Desc("self_support_for_school_ord.id")
	if req.EnterpriseId != 0 {
		sess.And("self_support_for_school_ord.enterprise_id =?", req.EnterpriseId)
	}
	if req.IsTeacher != 0 {
		if req.IsTeacher == 1 {
			sess.And("user_identity.identity =?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
		if req.IsTeacher == 2 {
			sess.And("user_identity.identity !=?", enum2.UserIdentityForCentralKitchenForTeacher)
		}
	}
	if req.StartDate != "" {
		sess.And("self_support_for_school_ord.face_time >= ?", req.StartDate)
	}
	if req.EndDate != "" {
		sess.And("self_support_for_school_ord.face_time <= ?", req.EndDate)
	}
	//if req.OrderStatus != 0 {
	sess.And("self_support_for_school_ord.order_status = ?", 1) // 支付状态 (1:待支付 2:支付成功)
	//}
	if req.OutTradeNo != "" {
		sess.And("self_support_for_school_ord.out_order_no like ?", "%"+req.OutTradeNo+"%")
	}
	if req.EnterpriseKind != 0 {
		sess.And("enterprise.kind = ?", req.EnterpriseKind)
	}

	if req.Name != "" {
		sess.And("user_identity.name like ?", "%"+req.Name+"%")
	}
	if req.Phone != "" {
		sess.And("user.phone like ?", "%"+req.Phone+"%")
	}
	if len(classWithUserIdentityIdsOne) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsOne)
	}
	if len(classWithUserIdentityIdsTwo) > 0 {
		sess.In("user_identity.id", classWithUserIdentityIdsTwo)
	}

	var m []*db.SelfSupportForSchoolOrdWithUserIdentity
	err = sess.
		Join("LEFT", "user_identity", "self_support_for_school_ord.user_identity_id = user_identity.id").
		Join("LEFT", "enterprise", "enterprise.id = self_support_for_school_ord.enterprise_id").
		Join("LEFT", "user", "user.id = user_identity.uid").
		Join("LEFT", "class_with_user", "class_with_user.user_identity_id = user_identity.id").
		Join("LEFT", "class", "class_with_user.class_id = class.id").
		Join("LEFT", "grade", "class.grade_id = grade.id").
		Desc("self_support_for_school_ord.face_time").Find(&m)
	if err != nil {
		return nil, err
	}

	//查询出所有的设备
	var deviceList []*model.Device
	err = db.Db.Where("enterprise_id != 0").Find(&deviceList)
	if err != nil {
		return nil, err
	}
	var deviceListMapping = map[string]model.Device{}
	for _, v := range deviceList {
		deviceListMapping[v.DeviceSn] = *v
	}
	for _, v := range m {
		resp = append(resp, md.SelfSupportForSchoolOrdListResp{
			EnterpriseId:     v.UserIdentity.EnterpriseId,
			EnterpriseName:   v.Enterprise.Name,
			Uid:              v.UserIdentity.Uid,
			UserIdentityId:   v.UserIdentity.Id,
			UserIdentityName: v.SelfSupportForSchoolOrd.Consumer,
			TotalPrice:       v.SelfSupportForSchoolOrd.TradeAmount,
			OutTradeNo:       v.SelfSupportForSchoolOrd.OutOrderNo,
			TradeNo:          v.SelfSupportForSchoolOrd.TradeNo,
			OrderStatus:      v.SelfSupportForSchoolOrd.OrderStatus,
			FaceTime:         v.SelfSupportForSchoolOrd.FaceTime,
			Phone:            v.User.Phone,
			Name:             v.UserIdentity.Name,
			Grade:            v.Grade.Name,
			GradeId:          v.Grade.Id,
			Class:            v.Class.Name,
			ClassId:          v.Class.Id,
			DeviceSn:         v.SelfSupportForSchoolOrd.DeviceSn,
			ShopName:         deviceListMapping[v.SelfSupportForSchoolOrd.DeviceSn].Name,
			CpMerchantId:     v.SelfSupportForSchoolOrd.CpMerchantId,
			DebtBusinessMsg:  v.SelfSupportForSchoolOrd.DebtBusinessMsg,
		})
	}
	return
}

func SelfSupportForSchoolOrdRefund(req md.SelfSupportForSchoolOrdRefundReq) (err error) {
	//1、查询出所有 `self_support_for_school_ord` 记录
	var m []model.SelfSupportForSchoolOrd
	selfSupportForSchoolOrd := db.SelfSupportForSchoolOrd{}
	selfSupportForSchoolOrd.Set("")
	err = selfSupportForSchoolOrd.Db.
		Where("order_status = ?", enum2.SelfSupportForSchoolOrdOrderStatusForSuccess).
		In("id", req.Ids).Find(&m)
	if err != nil {
		return err
	}

	sysCfgDb := db.SysCfgDb{}
	sysCfgDb.Set()
	sysCfg := sysCfgDb.SysCfgFindWithDb(enum2.OpenAlipayAppid, enum2.OpenAlipayAppPrivateKey, enum2.OpenAlipayPublicKey)

	companyWithAlipayAppAuthTokenDb := db.CompanyWithAlipayAppAuthTokenDb{}
	companyWithAlipayAppAuthTokenDb.Set()
	companyDb := db.EnterpriseDb{}
	companyDb.Set()
	for _, v := range m {
		//1、公司-支付宝应用授权 记录
		enterprise, err1 := companyDb.GetEnterprise(v.EnterpriseId)
		if err1 != nil {
			return err1
		}
		if enterprise == nil {
			continue
		}
		companyWithAlipayAppAuthToken, err1 := companyWithAlipayAppAuthTokenDb.GetCoWithAlipayAppAuthToken(enterprise.CompanyId)
		if err1 != nil {
			return err1
		}
		if companyWithAlipayAppAuthToken == nil {
			continue
		}

		//2、支付宝进行退款
		err1, _ = svc2.CurlAlipayTradeRefund(md2.CurlAlipayTradeRefundReq{
			Config: struct {
				PayAliAppId      string `json:"pay_ali_app_id" label:"支付宝开放平台-第三方应用-appid"`
				PayAliPrivateKey string `json:"pay_ali_private_key" label:"支付宝开放平台-第三方应用-接口加签-应用私钥"`
				PayAliPublicKey  string `json:"pay_ali_public_key" label:"支付宝开放平台-第三方应用-接口加签-支付宝公钥"`
			}{
				PayAliAppId:      sysCfg[enum2.OpenAlipayAppid],
				PayAliPrivateKey: sysCfg[enum2.OpenAlipayAppPrivateKey],
				PayAliPublicKey:  sysCfg[enum2.OpenAlipayPublicKey],
			},
			OutTradeNo:   v.OutOrderNo,
			RefundAmount: v.TradeAmount,
			RefundReason: "刷脸就餐-退款",
			OutRequestNo: utils.OrderUUID(v.Uid),
			AppAuthToken: companyWithAlipayAppAuthToken.AppAuthToken,
		})
		if err1 != nil {
			return err1
		}

		//3、修改 self_support_for_school_ord 的 `order_status` 字段
		selfSupportForSchoolOrd.Set(v.OutOrderNo)
		v.OrderStatus = enum2.SelfSupportForSchoolOrdOrderStatusForRefund
		selfSupportForSchoolOrd.SelfSupportForSchoolOrdUpdate(&v, "order_status")
	}

	return
}
